pub struct HnswBackend { /* private fields */ }Expand description
The in-memory HNSW backend persisted to a single fjall map.
Implementations
Sourceimpl HnswBackend
impl HnswBackend
Sourcepub fn open(
base: &str,
config: &NitriteConfig,
params: &VectorIndexConfig,
) -> NitriteResult<(Self, bool)>
pub fn open( base: &str, config: &NitriteConfig, params: &VectorIndexConfig, ) -> NitriteResult<(Self, bool)>
Opens (loading from the store) or creates the HNSW backend. The second
return value is true when existing index data was unreadable and the
(now wiped) index must be rebuilt from the collection.
Sourcepub fn insert(&self, id: u64, vector: Vec<f32>) -> NitriteResult<()>
pub fn insert(&self, id: u64, vector: Vec<f32>) -> NitriteResult<()>
Inserts or replaces the vector for id, persisting the change.
Sourcepub fn remove(&self, id: u64) -> NitriteResult<()>
pub fn remove(&self, id: u64) -> NitriteResult<()>
Removes the vector for id, persisting the change.